pipolars.DataQuality
====================

.. currentmodule:: pipolars

.. autoclass:: DataQuality

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~DataQuality.conjugate
      ~DataQuality.bit_length
      ~DataQuality.bit_count
      ~DataQuality.to_bytes
      ~DataQuality.from_bytes
      ~DataQuality.as_integer_ratio
      ~DataQuality.is_integer
      ~DataQuality.__init__
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~DataQuality.real
      ~DataQuality.imag
      ~DataQuality.numerator
      ~DataQuality.denominator
      ~DataQuality.GOOD
      ~DataQuality.SUBSTITUTED
      ~DataQuality.QUESTIONABLE
      ~DataQuality.BAD
      ~DataQuality.NO_DATA
      ~DataQuality.CALC_FAILED
   
   